@@ -20,9 +20,10 @@ class InstanceSettingsStore(BaseSettings):
 
 
 class UserSettingsStore(BaseSettings):
-    user_email: str
-    user_secret: str
-    user_id: str
+    email: str
+    password: str
+    id: str
+    handle: str
 
     class Config:
         env_file = ".env"
